order_maybe_unsorted_scratch

Function order_maybe_unsorted_scratch 

pub fn order_maybe_unsorted_scratch<I: Index>(
    n: usize,
    nnz_upper: usize,
) -> StackReq
computes the size and alignment of required workspace for computing the amd ordering of an unsorted matrix