order_scratch

Function order_scratch 

pub fn order_scratch<I: Index>(n: usize, nnz_upper: usize) -> StackReq
computes the size and alignment of required workspace for computing the amd ordering of a sorted matrix