pub struct FlopCount {
pub n_div: f64,
pub n_mult_subs_ldl: f64,
pub n_mult_subs_lu: f64,
}Expand description
flop count of the ldlt and lu factorizations if the provided ordering is used
Fields
n_div: f64number of division
n_mult_subs_ldl: f64number of multiplications and subtractions for the ldlt factorization
n_mult_subs_lu: f64number of multiplications and subtractions for the lu factorization