pub fn order<I: Index>(
perm: &mut [I],
perm_inv: &mut [I],
A: SymbolicSparseColMatRef<'_, I>,
control: Control,
stack: &mut MemStack,
) -> Result<FlopCount, FaerError>Expand description
computes the approximate minimum degree ordering for reducing the fill-in during the sparse cholesky factorization of a matrix with the sparsity pattern of $A + A^\top$